@@ -95,7 +95,12 @@ class RollbarNotifierMiddleware(object):
         
         # monkeypatch debug module
         if self._get_setting('patch_debugview'):
-            _patch_debugview(self._get_setting('web_base'))
+            try:
+                _patch_debugview(self._get_setting('web_base'))
+            except Exception, e:
+                log.error("Rollbar - unable to monkeypatch debugview to add 'View in Rollbar' link."
+                    " To disable, set `ROLLBAR['patch_debugview'] = False` in settings.py."
+                    " Exception was: %r", e)
 
     def _ensure_log_handler(self):
         """
